# pydrobert-pytorch
PyTorch utilities for ML, specifically speech.

## Installation

``pydrobert-pytorch`` is available through both Conda and PyPI.

``` bash
conda install -c sdrobert pydrobert-pytorch
pip install pydrobert-pytorch
```
